Asks the trainer to stop after the current step and save a checkpoint. Falls back to killing the process if it does not stop in time.
Asks the trainer to stop after the current step and save a checkpoint. Falls back to killing the process if it does not stop in time.