Every run, including ones started from the Shiny app, can be replayed as a script. The dataset path is the original source when it was a file.
Every run, including ones started from the Shiny app, can be replayed as a script. The dataset path is the original source when it was a file.