R/run.R
dragon_run.Rd
Runs live entirely on disk, so any run can be picked up from a new R session by its directory.
dragon_run(dir)
Path to a run directory (one containing config.json).
config.json
A dragon_run object.
dragon_run